# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceAgentCommandContent(object):
    """
    The contents of the command.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceAgentCommandContent object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this InstanceAgentCommandContent.
        :type source: oci.compute_instance_agent.models.InstanceAgentCommandSourceDetails

        :param output:
            The value to assign to the output property of this InstanceAgentCommandContent.
        :type output: oci.compute_instance_agent.models.InstanceAgentCommandOutputDetails

        """
        self.swagger_types = {
            'source': 'InstanceAgentCommandSourceDetails',
            'output': 'InstanceAgentCommandOutputDetails'
        }

        self.attribute_map = {
            'source': 'source',
            'output': 'output'
        }

        self._source = None
        self._output = None

    @property
    def source(self):
        """
        **[Required]** Gets the source of this InstanceAgentCommandContent.
        The source of the command.


        :return: The source of this InstanceAgentCommandContent.
        :rtype: oci.compute_instance_agent.models.InstanceAgentCommandSourceDetails
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this InstanceAgentCommandContent.
        The source of the command.


        :param source: The source of this InstanceAgentCommandContent.
        :type: oci.compute_instance_agent.models.InstanceAgentCommandSourceDetails
        """
        self._source = source

    @property
    def output(self):
        """
        Gets the output of this InstanceAgentCommandContent.
        The output destination for the command.


        :return: The output of this InstanceAgentCommandContent.
        :rtype: oci.compute_instance_agent.models.InstanceAgentCommandOutputDetails
        """
        return self._output

    @output.setter
    def output(self, output):
        """
        Sets the output of this InstanceAgentCommandContent.
        The output destination for the command.


        :param output: The output of this InstanceAgentCommandContent.
        :type: oci.compute_instance_agent.models.InstanceAgentCommandOutputDetails
        """
        self._output = output

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreatePublicationDetails(object):
    """
    The model for the parameters needed to create a publication.
    """

    #: A constant which can be used with the listing_type property of a CreatePublicationDetails.
    #: This constant has a value of "COMMUNITY"
    LISTING_TYPE_COMMUNITY = "COMMUNITY"

    #: A constant which can be used with the listing_type property of a CreatePublicationDetails.
    #: This constant has a value of "PARTNER"
    LISTING_TYPE_PARTNER = "PARTNER"

    #: A constant which can be used with the listing_type property of a CreatePublicationDetails.
    #: This constant has a value of "PRIVATE"
    LISTING_TYPE_PRIVATE = "PRIVATE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreatePublicationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param listing_type:
            The value to assign to the listing_type property of this CreatePublicationDetails.
            Allowed values for this property are: "COMMUNITY", "PARTNER", "PRIVATE"
        :type listing_type: str

        :param name:
            The value to assign to the name property of this CreatePublicationDetails.
        :type name: str

        :param short_description:
            The value to assign to the short_description property of this CreatePublicationDetails.
        :type short_description: str

        :param long_description:
            The value to assign to the long_description property of this CreatePublicationDetails.
        :type long_description: str

        :param support_contacts:
            The value to assign to the support_contacts property of this CreatePublicationDetails.
        :type support_contacts: list[oci.marketplace.models.SupportContact]

        :param compartment_id:
            The value to assign to the compartment_id property of this CreatePublicationDetails.
        :type compartment_id: str

        :param package_details:
            The value to assign to the package_details property of this CreatePublicationDetails.
        :type package_details: oci.marketplace.models.CreatePublicationPackage

        :param is_agreement_acknowledged:
            The value to assign to the is_agreement_acknowledged property of this CreatePublicationDetails.
        :type is_agreement_acknowledged: bool

        :param defined_tags:
            The value to assign to the defined_tags property of this CreatePublicationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreatePublicationDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'listing_type': 'str',
            'name': 'str',
            'short_description': 'str',
            'long_description': 'str',
            'support_contacts': 'list[SupportContact]',
            'compartment_id': 'str',
            'package_details': 'CreatePublicationPackage',
            'is_agreement_acknowledged': 'bool',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'listing_type': 'listingType',
            'name': 'name',
            'short_description': 'shortDescription',
            'long_description': 'longDescription',
            'support_contacts': 'supportContacts',
            'compartment_id': 'compartmentId',
            'package_details': 'packageDetails',
            'is_agreement_acknowledged': 'isAgreementAcknowledged',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._listing_type = None
        self._name = None
        self._short_description = None
        self._long_description = None
        self._support_contacts = None
        self._compartment_id = None
        self._package_details = None
        self._is_agreement_acknowledged = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def listing_type(self):
        """
        **[Required]** Gets the listing_type of this CreatePublicationDetails.
        The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.

        Allowed values for this property are: "COMMUNITY", "PARTNER", "PRIVATE"


        :return: The listing_type of this CreatePublicationDetails.
        :rtype: str
        """
        return self._listing_type

    @listing_type.setter
    def listing_type(self, listing_type):
        """
        Sets the listing_type of this CreatePublicationDetails.
        The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.


        :param listing_type: The listing_type of this CreatePublicationDetails.
        :type: str
        """
        allowed_values = ["COMMUNITY", "PARTNER", "PRIVATE"]
        if not value_allowed_none_or_none_sentinel(listing_type, allowed_values):
            raise ValueError(
                "Invalid value for `listing_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._listing_type = listing_type

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreatePublicationDetails.
        The name of the publication, which is also used in the listing.


        :return: The name of this CreatePublicationDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreatePublicationDetails.
        The name of the publication, which is also used in the listing.


        :param name: The name of this CreatePublicationDetails.
        :type: str
        """
        self._name = name

    @property
    def short_description(self):
        """
        **[Required]** Gets the short_description of this CreatePublicationDetails.
        A short description of the publication to use in the listing.


        :return: The short_description of this CreatePublicationDetails.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this CreatePublicationDetails.
        A short description of the publication to use in the listing.


        :param short_description: The short_description of this CreatePublicationDetails.
        :type: str
        """
        self._short_description = short_description

    @property
    def long_description(self):
        """
        Gets the long_description of this CreatePublicationDetails.
        A long description of the publication to use in the listing.


        :return: The long_description of this CreatePublicationDetails.
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """
        Sets the long_description of this CreatePublicationDetails.
        A long description of the publication to use in the listing.


        :param long_description: The long_description of this CreatePublicationDetails.
        :type: str
        """
        self._long_description = long_description

    @property
    def support_contacts(self):
        """
        **[Required]** Gets the support_contacts of this CreatePublicationDetails.
        Contact information for getting support from the publisher for the listing.


        :return: The support_contacts of this CreatePublicationDetails.
        :rtype: list[oci.marketplace.models.SupportContact]
        """
        return self._support_contacts

    @support_contacts.setter
    def support_contacts(self, support_contacts):
        """
        Sets the support_contacts of this CreatePublicationDetails.
        Contact information for getting support from the publisher for the listing.


        :param support_contacts: The support_contacts of this CreatePublicationDetails.
        :type: list[oci.marketplace.models.SupportContact]
        """
        self._support_contacts = support_contacts

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreatePublicationDetails.
        The `OCID`__ of the compartment where you want to create the publication.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreatePublicationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreatePublicationDetails.
        The `OCID`__ of the compartment where you want to create the publication.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreatePublicationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def package_details(self):
        """
        **[Required]** Gets the package_details of this CreatePublicationDetails.

        :return: The package_details of this CreatePublicationDetails.
        :rtype: oci.marketplace.models.CreatePublicationPackage
        """
        return self._package_details

    @package_details.setter
    def package_details(self, package_details):
        """
        Sets the package_details of this CreatePublicationDetails.

        :param package_details: The package_details of this CreatePublicationDetails.
        :type: oci.marketplace.models.CreatePublicationPackage
        """
        self._package_details = package_details

    @property
    def is_agreement_acknowledged(self):
        """
        **[Required]** Gets the is_agreement_acknowledged of this CreatePublicationDetails.
        Whether the publisher acknowledged that they have the right and authority to share the contents of the publication and that they accepted the Oracle terms of use agreements required to create a publication.


        :return: The is_agreement_acknowledged of this CreatePublicationDetails.
        :rtype: bool
        """
        return self._is_agreement_acknowledged

    @is_agreement_acknowledged.setter
    def is_agreement_acknowledged(self, is_agreement_acknowledged):
        """
        Sets the is_agreement_acknowledged of this CreatePublicationDetails.
        Whether the publisher acknowledged that they have the right and authority to share the contents of the publication and that they accepted the Oracle terms of use agreements required to create a publication.


        :param is_agreement_acknowledged: The is_agreement_acknowledged of this CreatePublicationDetails.
        :type: bool
        """
        self._is_agreement_acknowledged = is_agreement_acknowledged

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreatePublicationDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreatePublicationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreatePublicationDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreatePublicationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreatePublicationDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreatePublicationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreatePublicationDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreatePublicationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DetectStackDriftDetails(object):
    """
    The details for detecting drift in a stack
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DetectStackDriftDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_addresses:
            The value to assign to the resource_addresses property of this DetectStackDriftDetails.
        :type resource_addresses: list[str]

        """
        self.swagger_types = {
            'resource_addresses': 'list[str]'
        }

        self.attribute_map = {
            'resource_addresses': 'resourceAddresses'
        }

        self._resource_addresses = None

    @property
    def resource_addresses(self):
        """
        Gets the resource_addresses of this DetectStackDriftDetails.
        The list of resources in the specified stack to detect drift for. Each resource is identified by a resource address,
        which is a string derived from the resource type and name specified in the stack's Terraform configuration plus an optional index.
        For example, the resource address for the fourth Compute instance with the name \"test_instance\" is oci_core_instance.test_instance`3].
        For more details and examples of resource addresses, see the Terraform documentation at [Resource spec`__.

        __ https://www.terraform.io/docs/internals/resource-addressing.html#examples


        :return: The resource_addresses of this DetectStackDriftDetails.
        :rtype: list[str]
        """
        return self._resource_addresses

    @resource_addresses.setter
    def resource_addresses(self, resource_addresses):
        """
        Sets the resource_addresses of this DetectStackDriftDetails.
        The list of resources in the specified stack to detect drift for. Each resource is identified by a resource address,
        which is a string derived from the resource type and name specified in the stack's Terraform configuration plus an optional index.
        For example, the resource address for the fourth Compute instance with the name \"test_instance\" is oci_core_instance.test_instance`3].
        For more details and examples of resource addresses, see the Terraform documentation at [Resource spec`__.

        __ https://www.terraform.io/docs/internals/resource-addressing.html#examples


        :param resource_addresses: The resource_addresses of this DetectStackDriftDetails.
        :type: list[str]
        """
        self._resource_addresses = resource_addresses

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceAgentCommandExecution(object):
    """
    A command's execution summary.
    """

    #: A constant which can be used with the delivery_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "VISIBLE"
    DELIVERY_STATE_VISIBLE = "VISIBLE"

    #: A constant which can be used with the delivery_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "PENDING"
    DELIVERY_STATE_PENDING = "PENDING"

    #: A constant which can be used with the delivery_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "ACKED"
    DELIVERY_STATE_ACKED = "ACKED"

    #: A constant which can be used with the delivery_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "ACKED_CANCELED"
    DELIVERY_STATE_ACKED_CANCELED = "ACKED_CANCELED"

    #: A constant which can be used with the delivery_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "EXPIRED"
    DELIVERY_STATE_EXPIRED = "EXPIRED"

    #: A constant which can be used with the lifecycle_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "TIMED_OUT"
    LIFECYCLE_STATE_TIMED_OUT = "TIMED_OUT"

    #: A constant which can be used with the lifecycle_state property of a InstanceAgentCommandExecution.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceAgentCommandExecution object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_agent_command_id:
            The value to assign to the instance_agent_command_id property of this InstanceAgentCommandExecution.
        :type instance_agent_command_id: str

        :param instance_id:
            The value to assign to the instance_id property of this InstanceAgentCommandExecution.
        :type instance_id: str

        :param delivery_state:
            The value to assign to the delivery_state property of this InstanceAgentCommandExecution.
            Allowed values for this property are: "VISIBLE", "PENDING", "ACKED", "ACKED_CANCELED", "EXPIRED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type delivery_state: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this InstanceAgentCommandExecution.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "TIMED_OUT", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this InstanceAgentCommandExecution.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this InstanceAgentCommandExecution.
        :type time_updated: datetime

        :param sequence_number:
            The value to assign to the sequence_number property of this InstanceAgentCommandExecution.
        :type sequence_number: int

        :param display_name:
            The value to assign to the display_name property of this InstanceAgentCommandExecution.
        :type display_name: str

        :param content:
            The value to assign to the content property of this InstanceAgentCommandExecution.
        :type content: oci.compute_instance_agent.models.InstanceAgentCommandExecutionOutputContent

        """
        self.swagger_types = {
            'instance_agent_command_id': 'str',
            'instance_id': 'str',
            'delivery_state': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'sequence_number': 'int',
            'display_name': 'str',
            'content': 'InstanceAgentCommandExecutionOutputContent'
        }

        self.attribute_map = {
            'instance_agent_command_id': 'instanceAgentCommandId',
            'instance_id': 'instanceId',
            'delivery_state': 'deliveryState',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'sequence_number': 'sequenceNumber',
            'display_name': 'displayName',
            'content': 'content'
        }

        self._instance_agent_command_id = None
        self._instance_id = None
        self._delivery_state = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._sequence_number = None
        self._display_name = None
        self._content = None

    @property
    def instance_agent_command_id(self):
        """
        **[Required]** Gets the instance_agent_command_id of this InstanceAgentCommandExecution.
        The OCID of the command


        :return: The instance_agent_command_id of this InstanceAgentCommandExecution.
        :rtype: str
        """
        return self._instance_agent_command_id

    @instance_agent_command_id.setter
    def instance_agent_command_id(self, instance_agent_command_id):
        """
        Sets the instance_agent_command_id of this InstanceAgentCommandExecution.
        The OCID of the command


        :param instance_agent_command_id: The instance_agent_command_id of this InstanceAgentCommandExecution.
        :type: str
        """
        self._instance_agent_command_id = instance_agent_command_id

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this InstanceAgentCommandExecution.
        The OCID of the instance


        :return: The instance_id of this InstanceAgentCommandExecution.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this InstanceAgentCommandExecution.
        The OCID of the instance


        :param instance_id: The instance_id of this InstanceAgentCommandExecution.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def delivery_state(self):
        """
        **[Required]** Gets the delivery_state of this InstanceAgentCommandExecution.
        Specifies the command delivery state.
         * `VISIBLE` - The command is visible to instance.
         * `PENDING` - The command is pending ack from the instance.
         * `ACKED` - The command has been received and acked by the instance.
         * `ACKED_CANCELED` - The canceled command has been received and acked by the instance.
         * `EXPIRED` - The instance has not requested for commands and its delivery has expired.

        Allowed values for this property are: "VISIBLE", "PENDING", "ACKED", "ACKED_CANCELED", "EXPIRED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The delivery_state of this InstanceAgentCommandExecution.
        :rtype: str
        """
        return self._delivery_state

    @delivery_state.setter
    def delivery_state(self, delivery_state):
        """
        Sets the delivery_state of this InstanceAgentCommandExecution.
        Specifies the command delivery state.
         * `VISIBLE` - The command is visible to instance.
         * `PENDING` - The command is pending ack from the instance.
         * `ACKED` - The command has been received and acked by the instance.
         * `ACKED_CANCELED` - The canceled command has been received and acked by the instance.
         * `EXPIRED` - The instance has not requested for commands and its delivery has expired.


        :param delivery_state: The delivery_state of this InstanceAgentCommandExecution.
        :type: str
        """
        allowed_values = ["VISIBLE", "PENDING", "ACKED", "ACKED_CANCELED", "EXPIRED"]
        if not value_allowed_none_or_none_sentinel(delivery_state, allowed_values):
            delivery_state = 'UNKNOWN_ENUM_VALUE'
        self._delivery_state = delivery_state

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this InstanceAgentCommandExecution.
        command execution life cycle state.
        * `ACCEPTED` - The command execution has been accepted to run.
        * `IN_PROGRESS` - The command execution is in progress.
        * `SUCCEEDED` - The command execution is successful.
        * `FAILED` - The command execution has failed.
        * `TIMED_OUT` - The command execution has timedout.
        * `CANCELED` - The command execution has canceled.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "TIMED_OUT", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this InstanceAgentCommandExecution.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this InstanceAgentCommandExecution.
        command execution life cycle state.
        * `ACCEPTED` - The command execution has been accepted to run.
        * `IN_PROGRESS` - The command execution is in progress.
        * `SUCCEEDED` - The command execution is successful.
        * `FAILED` - The command execution has failed.
        * `TIMED_OUT` - The command execution has timedout.
        * `CANCELED` - The command execution has canceled.


        :param lifecycle_state: The lifecycle_state of this InstanceAgentCommandExecution.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "TIMED_OUT", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this InstanceAgentCommandExecution.
        The command creation date


        :return: The time_created of this InstanceAgentCommandExecution.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this InstanceAgentCommandExecution.
        The command creation date


        :param time_created: The time_created of this InstanceAgentCommandExecution.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this InstanceAgentCommandExecution.
        The command last updated at date.


        :return: The time_updated of this InstanceAgentCommandExecution.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this InstanceAgentCommandExecution.
        The command last updated at date.


        :param time_updated: The time_updated of this InstanceAgentCommandExecution.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def sequence_number(self):
        """
        **[Required]** Gets the sequence_number of this InstanceAgentCommandExecution.
        The large non-consecutive number that Run Command Service assigns to each created command.


        :return: The sequence_number of this InstanceAgentCommandExecution.
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """
        Sets the sequence_number of this InstanceAgentCommandExecution.
        The large non-consecutive number that Run Command Service assigns to each created command.


        :param sequence_number: The sequence_number of this InstanceAgentCommandExecution.
        :type: int
        """
        self._sequence_number = sequence_number

    @property
    def display_name(self):
        """
        Gets the display_name of this InstanceAgentCommandExecution.
        The user friendly display name of the command.


        :return: The display_name of this InstanceAgentCommandExecution.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this InstanceAgentCommandExecution.
        The user friendly display name of the command.


        :param display_name: The display_name of this InstanceAgentCommandExecution.
        :type: str
        """
        self._display_name = display_name

    @property
    def content(self):
        """
        **[Required]** Gets the content of this InstanceAgentCommandExecution.

        :return: The content of this InstanceAgentCommandExecution.
        :rtype: oci.compute_instance_agent.models.InstanceAgentCommandExecutionOutputContent
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this InstanceAgentCommandExecution.

        :param content: The content of this InstanceAgentCommandExecution.
        :type: oci.compute_instance_agent.models.InstanceAgentCommandExecutionOutputContent
        """
        self._content = content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .instance_configuration_volume_source_details import InstanceConfigurationVolumeSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationVolumeSourceFromVolumeBackupDetails(InstanceConfigurationVolumeSourceDetails):
    """
    Specifies the volume backup.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationVolumeSourceFromVolumeBackupDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.InstanceConfigurationVolumeSourceFromVolumeBackupDetails.type` attribute
        of this class is ``volumeBackup`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this InstanceConfigurationVolumeSourceFromVolumeBackupDetails.
        :type type: str

        :param id:
            The value to assign to the id property of this InstanceConfigurationVolumeSourceFromVolumeBackupDetails.
        :type id: str

        """
        self.swagger_types = {
            'type': 'str',
            'id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'id': 'id'
        }

        self._type = None
        self._id = None
        self._type = 'volumeBackup'

    @property
    def id(self):
        """
        Gets the id of this InstanceConfigurationVolumeSourceFromVolumeBackupDetails.
        The OCID of the volume backup.


        :return: The id of this InstanceConfigurationVolumeSourceFromVolumeBackupDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InstanceConfigurationVolumeSourceFromVolumeBackupDetails.
        The OCID of the volume backup.


        :param id: The id of this InstanceConfigurationVolumeSourceFromVolumeBackupDetails.
        :type: str
        """
        self._id = id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsMetaFunctionArgument(object):
    """
    LogAnalyticsMetaFunctionArgument
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsMetaFunctionArgument object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_override_output_fields:
            The value to assign to the is_override_output_fields property of this LogAnalyticsMetaFunctionArgument.
        :type is_override_output_fields: bool

        :param argument_display_name:
            The value to assign to the argument_display_name property of this LogAnalyticsMetaFunctionArgument.
        :type argument_display_name: str

        :param argument_example:
            The value to assign to the argument_example property of this LogAnalyticsMetaFunctionArgument.
        :type argument_example: str

        :param argument_service:
            The value to assign to the argument_service property of this LogAnalyticsMetaFunctionArgument.
        :type argument_service: str

        :param argument_data_type:
            The value to assign to the argument_data_type property of this LogAnalyticsMetaFunctionArgument.
        :type argument_data_type: str

        :param argument_description:
            The value to assign to the argument_description property of this LogAnalyticsMetaFunctionArgument.
        :type argument_description: str

        :param argument_name:
            The value to assign to the argument_name property of this LogAnalyticsMetaFunctionArgument.
        :type argument_name: str

        :param argument_order:
            The value to assign to the argument_order property of this LogAnalyticsMetaFunctionArgument.
        :type argument_order: int

        :param argument_type:
            The value to assign to the argument_type property of this LogAnalyticsMetaFunctionArgument.
        :type argument_type: int

        :param argument_id:
            The value to assign to the argument_id property of this LogAnalyticsMetaFunctionArgument.
        :type argument_id: int

        :param argument_lookup_column:
            The value to assign to the argument_lookup_column property of this LogAnalyticsMetaFunctionArgument.
        :type argument_lookup_column: str

        :param argument_lookup_column_position:
            The value to assign to the argument_lookup_column_position property of this LogAnalyticsMetaFunctionArgument.
        :type argument_lookup_column_position: int

        :param argument_value:
            The value to assign to the argument_value property of this LogAnalyticsMetaFunctionArgument.
        :type argument_value: str

        :param argument_reference:
            The value to assign to the argument_reference property of this LogAnalyticsMetaFunctionArgument.
        :type argument_reference: str

        """
        self.swagger_types = {
            'is_override_output_fields': 'bool',
            'argument_display_name': 'str',
            'argument_example': 'str',
            'argument_service': 'str',
            'argument_data_type': 'str',
            'argument_description': 'str',
            'argument_name': 'str',
            'argument_order': 'int',
            'argument_type': 'int',
            'argument_id': 'int',
            'argument_lookup_column': 'str',
            'argument_lookup_column_position': 'int',
            'argument_value': 'str',
            'argument_reference': 'str'
        }

        self.attribute_map = {
            'is_override_output_fields': 'isOverrideOutputFields',
            'argument_display_name': 'argumentDisplayName',
            'argument_example': 'argumentExample',
            'argument_service': 'argumentService',
            'argument_data_type': 'argumentDataType',
            'argument_description': 'argumentDescription',
            'argument_name': 'argumentName',
            'argument_order': 'argumentOrder',
            'argument_type': 'argumentType',
            'argument_id': 'argumentId',
            'argument_lookup_column': 'argumentLookupColumn',
            'argument_lookup_column_position': 'argumentLookupColumnPosition',
            'argument_value': 'argumentValue',
            'argument_reference': 'argumentReference'
        }

        self._is_override_output_fields = None
        self._argument_display_name = None
        self._argument_example = None
        self._argument_service = None
        self._argument_data_type = None
        self._argument_description = None
        self._argument_name = None
        self._argument_order = None
        self._argument_type = None
        self._argument_id = None
        self._argument_lookup_column = None
        self._argument_lookup_column_position = None
        self._argument_value = None
        self._argument_reference = None

    @property
    def is_override_output_fields(self):
        """
        Gets the is_override_output_fields of this LogAnalyticsMetaFunctionArgument.
        The override output fields.


        :return: The is_override_output_fields of this LogAnalyticsMetaFunctionArgument.
        :rtype: bool
        """
        return self._is_override_output_fields

    @is_override_output_fields.setter
    def is_override_output_fields(self, is_override_output_fields):
        """
        Sets the is_override_output_fields of this LogAnalyticsMetaFunctionArgument.
        The override output fields.


        :param is_override_output_fields: The is_override_output_fields of this LogAnalyticsMetaFunctionArgument.
        :type: bool
        """
        self._is_override_output_fields = is_override_output_fields

    @property
    def argument_display_name(self):
        """
        Gets the argument_display_name of this LogAnalyticsMetaFunctionArgument.
        The argument display name.


        :return: The argument_display_name of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_display_name

    @argument_display_name.setter
    def argument_display_name(self, argument_display_name):
        """
        Sets the argument_display_name of this LogAnalyticsMetaFunctionArgument.
        The argument display name.


        :param argument_display_name: The argument_display_name of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_display_name = argument_display_name

    @property
    def argument_example(self):
        """
        Gets the argument_example of this LogAnalyticsMetaFunctionArgument.
        The argument example.


        :return: The argument_example of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_example

    @argument_example.setter
    def argument_example(self, argument_example):
        """
        Sets the argument_example of this LogAnalyticsMetaFunctionArgument.
        The argument example.


        :param argument_example: The argument_example of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_example = argument_example

    @property
    def argument_service(self):
        """
        Gets the argument_service of this LogAnalyticsMetaFunctionArgument.
        The argument service.


        :return: The argument_service of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_service

    @argument_service.setter
    def argument_service(self, argument_service):
        """
        Sets the argument_service of this LogAnalyticsMetaFunctionArgument.
        The argument service.


        :param argument_service: The argument_service of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_service = argument_service

    @property
    def argument_data_type(self):
        """
        Gets the argument_data_type of this LogAnalyticsMetaFunctionArgument.
        The argument data type.


        :return: The argument_data_type of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_data_type

    @argument_data_type.setter
    def argument_data_type(self, argument_data_type):
        """
        Sets the argument_data_type of this LogAnalyticsMetaFunctionArgument.
        The argument data type.


        :param argument_data_type: The argument_data_type of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_data_type = argument_data_type

    @property
    def argument_description(self):
        """
        Gets the argument_description of this LogAnalyticsMetaFunctionArgument.
        The argument description.


        :return: The argument_description of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_description

    @argument_description.setter
    def argument_description(self, argument_description):
        """
        Sets the argument_description of this LogAnalyticsMetaFunctionArgument.
        The argument description.


        :param argument_description: The argument_description of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_description = argument_description

    @property
    def argument_name(self):
        """
        Gets the argument_name of this LogAnalyticsMetaFunctionArgument.
        The argument name.


        :return: The argument_name of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_name

    @argument_name.setter
    def argument_name(self, argument_name):
        """
        Sets the argument_name of this LogAnalyticsMetaFunctionArgument.
        The argument name.


        :param argument_name: The argument_name of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_name = argument_name

    @property
    def argument_order(self):
        """
        Gets the argument_order of this LogAnalyticsMetaFunctionArgument.
        The argument order.


        :return: The argument_order of this LogAnalyticsMetaFunctionArgument.
        :rtype: int
        """
        return self._argument_order

    @argument_order.setter
    def argument_order(self, argument_order):
        """
        Sets the argument_order of this LogAnalyticsMetaFunctionArgument.
        The argument order.


        :param argument_order: The argument_order of this LogAnalyticsMetaFunctionArgument.
        :type: int
        """
        self._argument_order = argument_order

    @property
    def argument_type(self):
        """
        Gets the argument_type of this LogAnalyticsMetaFunctionArgument.
        The argument type.


        :return: The argument_type of this LogAnalyticsMetaFunctionArgument.
        :rtype: int
        """
        return self._argument_type

    @argument_type.setter
    def argument_type(self, argument_type):
        """
        Sets the argument_type of this LogAnalyticsMetaFunctionArgument.
        The argument type.


        :param argument_type: The argument_type of this LogAnalyticsMetaFunctionArgument.
        :type: int
        """
        self._argument_type = argument_type

    @property
    def argument_id(self):
        """
        Gets the argument_id of this LogAnalyticsMetaFunctionArgument.
        The argument unique identifier.


        :return: The argument_id of this LogAnalyticsMetaFunctionArgument.
        :rtype: int
        """
        return self._argument_id

    @argument_id.setter
    def argument_id(self, argument_id):
        """
        Sets the argument_id of this LogAnalyticsMetaFunctionArgument.
        The argument unique identifier.


        :param argument_id: The argument_id of this LogAnalyticsMetaFunctionArgument.
        :type: int
        """
        self._argument_id = argument_id

    @property
    def argument_lookup_column(self):
        """
        Gets the argument_lookup_column of this LogAnalyticsMetaFunctionArgument.
        The lookup column.


        :return: The argument_lookup_column of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_lookup_column

    @argument_lookup_column.setter
    def argument_lookup_column(self, argument_lookup_column):
        """
        Sets the argument_lookup_column of this LogAnalyticsMetaFunctionArgument.
        The lookup column.


        :param argument_lookup_column: The argument_lookup_column of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_lookup_column = argument_lookup_column

    @property
    def argument_lookup_column_position(self):
        """
        Gets the argument_lookup_column_position of this LogAnalyticsMetaFunctionArgument.
        The lookup column position.


        :return: The argument_lookup_column_position of this LogAnalyticsMetaFunctionArgument.
        :rtype: int
        """
        return self._argument_lookup_column_position

    @argument_lookup_column_position.setter
    def argument_lookup_column_position(self, argument_lookup_column_position):
        """
        Sets the argument_lookup_column_position of this LogAnalyticsMetaFunctionArgument.
        The lookup column position.


        :param argument_lookup_column_position: The argument_lookup_column_position of this LogAnalyticsMetaFunctionArgument.
        :type: int
        """
        self._argument_lookup_column_position = argument_lookup_column_position

    @property
    def argument_value(self):
        """
        Gets the argument_value of this LogAnalyticsMetaFunctionArgument.
        The argument value.


        :return: The argument_value of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_value

    @argument_value.setter
    def argument_value(self, argument_value):
        """
        Sets the argument_value of this LogAnalyticsMetaFunctionArgument.
        The argument value.


        :param argument_value: The argument_value of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_value = argument_value

    @property
    def argument_reference(self):
        """
        Gets the argument_reference of this LogAnalyticsMetaFunctionArgument.
        The argument unique identifier as a string.


        :return: The argument_reference of this LogAnalyticsMetaFunctionArgument.
        :rtype: str
        """
        return self._argument_reference

    @argument_reference.setter
    def argument_reference(self, argument_reference):
        """
        Sets the argument_reference of this LogAnalyticsMetaFunctionArgument.
        The argument unique identifier as a string.


        :param argument_reference: The argument_reference of this LogAnalyticsMetaFunctionArgument.
        :type: str
        """
        self._argument_reference = argument_reference

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryResultRowTypeSummary(object):
    """
    A summary of the datatype, unit and related metadata of an individual row element of a query result row that is returned.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryResultRowTypeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_type:
            The value to assign to the data_type property of this QueryResultRowTypeSummary.
        :type data_type: str

        :param unit:
            The value to assign to the unit property of this QueryResultRowTypeSummary.
        :type unit: str

        :param display_name:
            The value to assign to the display_name property of this QueryResultRowTypeSummary.
        :type display_name: str

        :param expression:
            The value to assign to the expression property of this QueryResultRowTypeSummary.
        :type expression: str

        :param query_result_row_type_summaries:
            The value to assign to the query_result_row_type_summaries property of this QueryResultRowTypeSummary.
        :type query_result_row_type_summaries: list[oci.apm_traces.models.QueryResultRowTypeSummary]

        """
        self.swagger_types = {
            'data_type': 'str',
            'unit': 'str',
            'display_name': 'str',
            'expression': 'str',
            'query_result_row_type_summaries': 'list[QueryResultRowTypeSummary]'
        }

        self.attribute_map = {
            'data_type': 'dataType',
            'unit': 'unit',
            'display_name': 'displayName',
            'expression': 'expression',
            'query_result_row_type_summaries': 'queryResultRowTypeSummaries'
        }

        self._data_type = None
        self._unit = None
        self._display_name = None
        self._expression = None
        self._query_result_row_type_summaries = None

    @property
    def data_type(self):
        """
        Gets the data_type of this QueryResultRowTypeSummary.
        Datatype of the query result row element.


        :return: The data_type of this QueryResultRowTypeSummary.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this QueryResultRowTypeSummary.
        Datatype of the query result row element.


        :param data_type: The data_type of this QueryResultRowTypeSummary.
        :type: str
        """
        self._data_type = data_type

    @property
    def unit(self):
        """
        Gets the unit of this QueryResultRowTypeSummary.
        Granular unit in which the query result row element's data is represented.


        :return: The unit of this QueryResultRowTypeSummary.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this QueryResultRowTypeSummary.
        Granular unit in which the query result row element's data is represented.


        :param unit: The unit of this QueryResultRowTypeSummary.
        :type: str
        """
        self._unit = unit

    @property
    def display_name(self):
        """
        Gets the display_name of this QueryResultRowTypeSummary.
        Alias name if an alias is used for the query result row element or an assigned display name from the query language
        in some default cases.


        :return: The display_name of this QueryResultRowTypeSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this QueryResultRowTypeSummary.
        Alias name if an alias is used for the query result row element or an assigned display name from the query language
        in some default cases.


        :param display_name: The display_name of this QueryResultRowTypeSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def expression(self):
        """
        Gets the expression of this QueryResultRowTypeSummary.
        Actual show expression in the user typed query that produced this column.


        :return: The expression of this QueryResultRowTypeSummary.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """
        Sets the expression of this QueryResultRowTypeSummary.
        Actual show expression in the user typed query that produced this column.


        :param expression: The expression of this QueryResultRowTypeSummary.
        :type: str
        """
        self._expression = expression

    @property
    def query_result_row_type_summaries(self):
        """
        Gets the query_result_row_type_summaries of this QueryResultRowTypeSummary.
        A query result row type summary object that represents a nested table structure.


        :return: The query_result_row_type_summaries of this QueryResultRowTypeSummary.
        :rtype: list[oci.apm_traces.models.QueryResultRowTypeSummary]
        """
        return self._query_result_row_type_summaries

    @query_result_row_type_summaries.setter
    def query_result_row_type_summaries(self, query_result_row_type_summaries):
        """
        Sets the query_result_row_type_summaries of this QueryResultRowTypeSummary.
        A query result row type summary object that represents a nested table structure.


        :param query_result_row_type_summaries: The query_result_row_type_summaries of this QueryResultRowTypeSummary.
        :type: list[oci.apm_traces.models.QueryResultRowTypeSummary]
        """
        self._query_result_row_type_summaries = query_result_row_type_summaries

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UserSummary(object):
    """
    The summary of information about the database user. It includes details such as user type, account status,
    last login time, user creation time, authentication type, user profile, and time and date of the last password change.
    It also contains the user category derived from these user details, as well as granted privileges.
    """

    #: A constant which can be used with the user_category property of a UserSummary.
    #: This constant has a value of "CRITICAL"
    USER_CATEGORY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the user_category property of a UserSummary.
    #: This constant has a value of "HIGH"
    USER_CATEGORY_HIGH = "HIGH"

    #: A constant which can be used with the user_category property of a UserSummary.
    #: This constant has a value of "MEDIUM"
    USER_CATEGORY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the user_category property of a UserSummary.
    #: This constant has a value of "LOW"
    USER_CATEGORY_LOW = "LOW"

    #: A constant which can be used with the account_status property of a UserSummary.
    #: This constant has a value of "OPEN"
    ACCOUNT_STATUS_OPEN = "OPEN"

    #: A constant which can be used with the account_status property of a UserSummary.
    #: This constant has a value of "LOCKED"
    ACCOUNT_STATUS_LOCKED = "LOCKED"

    #: A constant which can be used with the account_status property of a UserSummary.
    #: This constant has a value of "EXPIRED"
    ACCOUNT_STATUS_EXPIRED = "EXPIRED"

    #: A constant which can be used with the account_status property of a UserSummary.
    #: This constant has a value of "EXPIRED_AND_LOCKED"
    ACCOUNT_STATUS_EXPIRED_AND_LOCKED = "EXPIRED_AND_LOCKED"

    #: A constant which can be used with the account_status property of a UserSummary.
    #: This constant has a value of "NONE"
    ACCOUNT_STATUS_NONE = "NONE"

    #: A constant which can be used with the authentication_type property of a UserSummary.
    #: This constant has a value of "PASSWORD"
    AUTHENTICATION_TYPE_PASSWORD = "PASSWORD"

    #: A constant which can be used with the authentication_type property of a UserSummary.
    #: This constant has a value of "NONE"
    AUTHENTICATION_TYPE_NONE = "NONE"

    #: A constant which can be used with the user_types property of a UserSummary.
    #: This constant has a value of "ADMIN_PRIVILEGED"
    USER_TYPES_ADMIN_PRIVILEGED = "ADMIN_PRIVILEGED"

    #: A constant which can be used with the user_types property of a UserSummary.
    #: This constant has a value of "APPLICATION"
    USER_TYPES_APPLICATION = "APPLICATION"

    #: A constant which can be used with the user_types property of a UserSummary.
    #: This constant has a value of "PRIVILEGED"
    USER_TYPES_PRIVILEGED = "PRIVILEGED"

    #: A constant which can be used with the user_types property of a UserSummary.
    #: This constant has a value of "SCHEMA"
    USER_TYPES_SCHEMA = "SCHEMA"

    #: A constant which can be used with the user_types property of a UserSummary.
    #: This constant has a value of "NON_PRIVILEGED"
    USER_TYPES_NON_PRIVILEGED = "NON_PRIVILEGED"

    #: A constant which can be used with the admin_roles property of a UserSummary.
    #: This constant has a value of "PDB_DBA"
    ADMIN_ROLES_PDB_DBA = "PDB_DBA"

    #: A constant which can be used with the admin_roles property of a UserSummary.
    #: This constant has a value of "DBA"
    ADMIN_ROLES_DBA = "DBA"

    #: A constant which can be used with the admin_roles property of a UserSummary.
    #: This constant has a value of "DV_ADMIN"
    ADMIN_ROLES_DV_ADMIN = "DV_ADMIN"

    #: A constant which can be used with the admin_roles property of a UserSummary.
    #: This constant has a value of "AUDIT_ADMIN"
    ADMIN_ROLES_AUDIT_ADMIN = "AUDIT_ADMIN"

    def __init__(self, **kwargs):
        """
        Initializes a new UserSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this UserSummary.
        :type key: str

        :param user_name:
            The value to assign to the user_name property of this UserSummary.
        :type user_name: str

        :param user_category:
            The value to assign to the user_category property of this UserSummary.
            Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type user_category: str

        :param account_status:
            The value to assign to the account_status property of this UserSummary.
            Allowed values for this property are: "OPEN", "LOCKED", "EXPIRED", "EXPIRED_AND_LOCKED", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type account_status: str

        :param target_id:
            The value to assign to the target_id property of this UserSummary.
        :type target_id: str

        :param time_last_login:
            The value to assign to the time_last_login property of this UserSummary.
        :type time_last_login: datetime

        :param time_user_created:
            The value to assign to the time_user_created property of this UserSummary.
        :type time_user_created: datetime

        :param authentication_type:
            The value to assign to the authentication_type property of this UserSummary.
            Allowed values for this property are: "PASSWORD", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type authentication_type: str

        :param user_profile:
            The value to assign to the user_profile property of this UserSummary.
        :type user_profile: str

        :param time_password_changed:
            The value to assign to the time_password_changed property of this UserSummary.
        :type time_password_changed: datetime

        :param user_types:
            The value to assign to the user_types property of this UserSummary.
            Allowed values for items in this list are: "ADMIN_PRIVILEGED", "APPLICATION", "PRIVILEGED", "SCHEMA", "NON_PRIVILEGED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type user_types: list[str]

        :param admin_roles:
            The value to assign to the admin_roles property of this UserSummary.
            Allowed values for items in this list are: "PDB_DBA", "DBA", "DV_ADMIN", "AUDIT_ADMIN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type admin_roles: list[str]

        """
        self.swagger_types = {
            'key': 'str',
            'user_name': 'str',
            'user_category': 'str',
            'account_status': 'str',
            'target_id': 'str',
            'time_last_login': 'datetime',
            'time_user_created': 'datetime',
            'authentication_type': 'str',
            'user_profile': 'str',
            'time_password_changed': 'datetime',
            'user_types': 'list[str]',
            'admin_roles': 'list[str]'
        }

        self.attribute_map = {
            'key': 'key',
            'user_name': 'userName',
            'user_category': 'userCategory',
            'account_status': 'accountStatus',
            'target_id': 'targetId',
            'time_last_login': 'timeLastLogin',
            'time_user_created': 'timeUserCreated',
            'authentication_type': 'authenticationType',
            'user_profile': 'userProfile',
            'time_password_changed': 'timePasswordChanged',
            'user_types': 'userTypes',
            'admin_roles': 'adminRoles'
        }

        self._key = None
        self._user_name = None
        self._user_category = None
        self._account_status = None
        self._target_id = None
        self._time_last_login = None
        self._time_user_created = None
        self._authentication_type = None
        self._user_profile = None
        self._time_password_changed = None
        self._user_types = None
        self._admin_roles = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this UserSummary.
        The unique user key. This is a system-generated identifier. Use ListUsers to get the user key for a user.


        :return: The key of this UserSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this UserSummary.
        The unique user key. This is a system-generated identifier. Use ListUsers to get the user key for a user.


        :param key: The key of this UserSummary.
        :type: str
        """
        self._key = key

    @property
    def user_name(self):
        """
        **[Required]** Gets the user_name of this UserSummary.
        The database user name.


        :return: The user_name of this UserSummary.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this UserSummary.
        The database user name.


        :param user_name: The user_name of this UserSummary.
        :type: str
        """
        self._user_name = user_name

    @property
    def user_category(self):
        """
        Gets the user_category of this UserSummary.
        The user category based on the privileges and other details of the user.

        Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The user_category of this UserSummary.
        :rtype: str
        """
        return self._user_category

    @user_category.setter
    def user_category(self, user_category):
        """
        Sets the user_category of this UserSummary.
        The user category based on the privileges and other details of the user.


        :param user_category: The user_category of this UserSummary.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MEDIUM", "LOW"]
        if not value_allowed_none_or_none_sentinel(user_category, allowed_values):
            user_category = 'UNKNOWN_ENUM_VALUE'
        self._user_category = user_category

    @property
    def account_status(self):
        """
        Gets the account_status of this UserSummary.
        The user account status.

        Allowed values for this property are: "OPEN", "LOCKED", "EXPIRED", "EXPIRED_AND_LOCKED", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The account_status of this UserSummary.
        :rtype: str
        """
        return self._account_status

    @account_status.setter
    def account_status(self, account_status):
        """
        Sets the account_status of this UserSummary.
        The user account status.


        :param account_status: The account_status of this UserSummary.
        :type: str
        """
        allowed_values = ["OPEN", "LOCKED", "EXPIRED", "EXPIRED_AND_LOCKED", "NONE"]
        if not value_allowed_none_or_none_sentinel(account_status, allowed_values):
            account_status = 'UNKNOWN_ENUM_VALUE'
        self._account_status = account_status

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this UserSummary.
        The OCID of the target database.


        :return: The target_id of this UserSummary.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this UserSummary.
        The OCID of the target database.


        :param target_id: The target_id of this UserSummary.
        :type: str
        """
        self._target_id = target_id

    @property
    def time_last_login(self):
        """
        Gets the time_last_login of this UserSummary.
        The date and time when the user last logged in, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_last_login of this UserSummary.
        :rtype: datetime
        """
        return self._time_last_login

    @time_last_login.setter
    def time_last_login(self, time_last_login):
        """
        Sets the time_last_login of this UserSummary.
        The date and time when the user last logged in, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_last_login: The time_last_login of this UserSummary.
        :type: datetime
        """
        self._time_last_login = time_last_login

    @property
    def time_user_created(self):
        """
        Gets the time_user_created of this UserSummary.
        The date and time when the user was created in the database, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_user_created of this UserSummary.
        :rtype: datetime
        """
        return self._time_user_created

    @time_user_created.setter
    def time_user_created(self, time_user_created):
        """
        Sets the time_user_created of this UserSummary.
        The date and time when the user was created in the database, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_user_created: The time_user_created of this UserSummary.
        :type: datetime
        """
        self._time_user_created = time_user_created

    @property
    def authentication_type(self):
        """
        Gets the authentication_type of this UserSummary.
        The user authentication method.

        Allowed values for this property are: "PASSWORD", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The authentication_type of this UserSummary.
        :rtype: str
        """
        return self._authentication_type

    @authentication_type.setter
    def authentication_type(self, authentication_type):
        """
        Sets the authentication_type of this UserSummary.
        The user authentication method.


        :param authentication_type: The authentication_type of this UserSummary.
        :type: str
        """
        allowed_values = ["PASSWORD", "NONE"]
        if not value_allowed_none_or_none_sentinel(authentication_type, allowed_values):
            authentication_type = 'UNKNOWN_ENUM_VALUE'
        self._authentication_type = authentication_type

    @property
    def user_profile(self):
        """
        Gets the user_profile of this UserSummary.
        The user profile name.


        :return: The user_profile of this UserSummary.
        :rtype: str
        """
        return self._user_profile

    @user_profile.setter
    def user_profile(self, user_profile):
        """
        Sets the user_profile of this UserSummary.
        The user profile name.


        :param user_profile: The user_profile of this UserSummary.
        :type: str
        """
        self._user_profile = user_profile

    @property
    def time_password_changed(self):
        """
        Gets the time_password_changed of this UserSummary.
        The date and time when the user password was last changed, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_password_changed of this UserSummary.
        :rtype: datetime
        """
        return self._time_password_changed

    @time_password_changed.setter
    def time_password_changed(self, time_password_changed):
        """
        Sets the time_password_changed of this UserSummary.
        The date and time when the user password was last changed, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_password_changed: The time_password_changed of this UserSummary.
        :type: datetime
        """
        self._time_password_changed = time_password_changed

    @property
    def user_types(self):
        """
        Gets the user_types of this UserSummary.
        The user type, which can be a combination of the following:

        'Admin Privileged': The user has administrative privileges.
        'Application': The user is an Oracle E-Business Suite Applications (EBS) or Fusion Applications (FA) user.
        'Privileged': The user is a privileged user.
        'Schema': The user is EXPIRED & LOCKED / EXPIRED / LOCKED, or a schema-only account (authentication type is NONE).
        'Non-privileged': The user is a non-privileged user.

        Allowed values for items in this list are: "ADMIN_PRIVILEGED", "APPLICATION", "PRIVILEGED", "SCHEMA", "NON_PRIVILEGED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The user_types of this UserSummary.
        :rtype: list[str]
        """
        return self._user_types

    @user_types.setter
    def user_types(self, user_types):
        """
        Sets the user_types of this UserSummary.
        The user type, which can be a combination of the following:

        'Admin Privileged': The user has administrative privileges.
        'Application': The user is an Oracle E-Business Suite Applications (EBS) or Fusion Applications (FA) user.
        'Privileged': The user is a privileged user.
        'Schema': The user is EXPIRED & LOCKED / EXPIRED / LOCKED, or a schema-only account (authentication type is NONE).
        'Non-privileged': The user is a non-privileged user.


        :param user_types: The user_types of this UserSummary.
        :type: list[str]
        """
        allowed_values = ["ADMIN_PRIVILEGED", "APPLICATION", "PRIVILEGED", "SCHEMA", "NON_PRIVILEGED"]
        if user_types:
            user_types[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in user_types]
        self._user_types = user_types

    @property
    def admin_roles(self):
        """
        Gets the admin_roles of this UserSummary.
        The admin roles granted to the user.

        Allowed values for items in this list are: "PDB_DBA", "DBA", "DV_ADMIN", "AUDIT_ADMIN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The admin_roles of this UserSummary.
        :rtype: list[str]
        """
        return self._admin_roles

    @admin_roles.setter
    def admin_roles(self, admin_roles):
        """
        Sets the admin_roles of this UserSummary.
        The admin roles granted to the user.


        :param admin_roles: The admin_roles of this UserSummary.
        :type: list[str]
        """
        allowed_values = ["PDB_DBA", "DBA", "DV_ADMIN", "AUDIT_ADMIN"]
        if admin_roles:
            admin_roles[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in admin_roles]
        self._admin_roles = admin_roles

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .platform_config import PlatformConfig
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AmdRomeBmPlatformConfig(PlatformConfig):
    """
    The platform configuration of a bare metal instance that uses the AMD Rome platform.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AmdRomeBmPlatformConfig object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.AmdRomeBmPlatformConfig.type` attribute
        of this class is ``AMD_ROME_BM`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AmdRomeBmPlatformConfig.
            Allowed values for this property are: "AMD_MILAN_BM", "AMD_ROME_BM", "INTEL_SKYLAKE_BM", "AMD_VM", "INTEL_VM"
        :type type: str

        :param is_secure_boot_enabled:
            The value to assign to the is_secure_boot_enabled property of this AmdRomeBmPlatformConfig.
        :type is_secure_boot_enabled: bool

        :param is_trusted_platform_module_enabled:
            The value to assign to the is_trusted_platform_module_enabled property of this AmdRomeBmPlatformConfig.
        :type is_trusted_platform_module_enabled: bool

        :param is_measured_boot_enabled:
            The value to assign to the is_measured_boot_enabled property of this AmdRomeBmPlatformConfig.
        :type is_measured_boot_enabled: bool

        """
        self.swagger_types = {
            'type': 'str',
            'is_secure_boot_enabled': 'bool',
            'is_trusted_platform_module_enabled': 'bool',
            'is_measured_boot_enabled': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'is_secure_boot_enabled': 'isSecureBootEnabled',
            'is_trusted_platform_module_enabled': 'isTrustedPlatformModuleEnabled',
            'is_measured_boot_enabled': 'isMeasuredBootEnabled'
        }

        self._type = None
        self._is_secure_boot_enabled = None
        self._is_trusted_platform_module_enabled = None
        self._is_measured_boot_enabled = None
        self._type = 'AMD_ROME_BM'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .rule import Rule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ControlAccessUsingHttpMethodsRule(Rule):
    """
    An object that represents the action of returning a specified response code when the requested HTTP method is not in
    the list of allowed methods for the listener. The load balancer does not forward a disallowed request to the back end
    servers. The default response code is `405 Method Not Allowed`.

    If you set the response code to `405` or leave it blank, the system adds an \"allow\" response header that contains a
    list of the allowed methods for the listener. If you set the response code to anything other than `405` (or blank),
    the system does not add the \"allow\" response header with a list of allowed methods.

    This rule applies only to HTTP listeners. No more than one `ControlAccessUsingHttpMethodsRule` object can be present in
    a given listener.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ControlAccessUsingHttpMethodsRule object with values from keyword arguments. The default value of the :py:attr:`~oci.load_balancer.models.ControlAccessUsingHttpMethodsRule.action` attribute
        of this class is ``CONTROL_ACCESS_USING_HTTP_METHODS`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action:
            The value to assign to the action property of this ControlAccessUsingHttpMethodsRule.
            Allowed values for this property are: "ADD_HTTP_REQUEST_HEADER", "EXTEND_HTTP_REQUEST_HEADER_VALUE", "REMOVE_HTTP_REQUEST_HEADER", "ADD_HTTP_RESPONSE_HEADER", "EXTEND_HTTP_RESPONSE_HEADER_VALUE", "REMOVE_HTTP_RESPONSE_HEADER", "ALLOW", "CONTROL_ACCESS_USING_HTTP_METHODS", "REDIRECT", "HTTP_HEADER"
        :type action: str

        :param allowed_methods:
            The value to assign to the allowed_methods property of this ControlAccessUsingHttpMethodsRule.
        :type allowed_methods: list[str]

        :param status_code:
            The value to assign to the status_code property of this ControlAccessUsingHttpMethodsRule.
        :type status_code: int

        """
        self.swagger_types = {
            'action': 'str',
            'allowed_methods': 'list[str]',
            'status_code': 'int'
        }

        self.attribute_map = {
            'action': 'action',
            'allowed_methods': 'allowedMethods',
            'status_code': 'statusCode'
        }

        self._action = None
        self._allowed_methods = None
        self._status_code = None
        self._action = 'CONTROL_ACCESS_USING_HTTP_METHODS'

    @property
    def allowed_methods(self):
        """
        **[Required]** Gets the allowed_methods of this ControlAccessUsingHttpMethodsRule.
        The list of HTTP methods allowed for this listener.

        By default, you can specify only the standard HTTP methods defined in the
        `HTTP Method Registry`__. You can also
        see a list of supported standard HTTP methods in the Load Balancing service documentation at
        `Managing Rule Sets`__.

        Your backend application must be able to handle the methods specified in this list.

        The list of HTTP methods is extensible. If you need to configure custom HTTP methods, contact
        `My Oracle Support`__ to remove the restriction for your tenancy.

        Example: [\"GET\", \"PUT\", \"POST\", \"PROPFIND\"]

        __ http://www.iana.org/assignments/http-methods/http-methods.xhtml
        __ https://docs.cloud.oracle.com/Content/Balance/Tasks/managingrulesets.htm
        __ http://support.oracle.com/


        :return: The allowed_methods of this ControlAccessUsingHttpMethodsRule.
        :rtype: list[str]
        """
        return self._allowed_methods

    @allowed_methods.setter
    def allowed_methods(self, allowed_methods):
        """
        Sets the allowed_methods of this ControlAccessUsingHttpMethodsRule.
        The list of HTTP methods allowed for this listener.

        By default, you can specify only the standard HTTP methods defined in the
        `HTTP Method Registry`__. You can also
        see a list of supported standard HTTP methods in the Load Balancing service documentation at
        `Managing Rule Sets`__.

        Your backend application must be able to handle the methods specified in this list.

        The list of HTTP methods is extensible. If you need to configure custom HTTP methods, contact
        `My Oracle Support`__ to remove the restriction for your tenancy.

        Example: [\"GET\", \"PUT\", \"POST\", \"PROPFIND\"]

        __ http://www.iana.org/assignments/http-methods/http-methods.xhtml
        __ https://docs.cloud.oracle.com/Content/Balance/Tasks/managingrulesets.htm
        __ http://support.oracle.com/


        :param allowed_methods: The allowed_methods of this ControlAccessUsingHttpMethodsRule.
        :type: list[str]
        """
        self._allowed_methods = allowed_methods

    @property
    def status_code(self):
        """
        Gets the status_code of this ControlAccessUsingHttpMethodsRule.
        The HTTP status code to return when the requested HTTP method is not in the list of allowed methods.
        The associated status line returned with the code is mapped from the standard HTTP specification. The
        default value is `405 (Method Not Allowed)`.

        Example: 403


        :return: The status_code of this ControlAccessUsingHttpMethodsRule.
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """
        Sets the status_code of this ControlAccessUsingHttpMethodsRule.
        The HTTP status code to return when the requested HTTP method is not in the list of allowed methods.
        The associated status line returned with the code is mapped from the standard HTTP specification. The
        default value is `405 (Method Not Allowed)`.

        Example: 403


        :param status_code: The status_code of this ControlAccessUsingHttpMethodsRule.
        :type: int
        """
        self._status_code = status_code

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgAttachmentNetworkDetails(object):
    """
    DrgAttachmentNetworkDetails model.
    """

    #: A constant which can be used with the type property of a DrgAttachmentNetworkDetails.
    #: This constant has a value of "VCN"
    TYPE_VCN = "VCN"

    #: A constant which can be used with the type property of a DrgAttachmentNetworkDetails.
    #: This constant has a value of "IPSEC_TUNNEL"
    TYPE_IPSEC_TUNNEL = "IPSEC_TUNNEL"

    #: A constant which can be used with the type property of a DrgAttachmentNetworkDetails.
    #: This constant has a value of "VIRTUAL_CIRCUIT"
    TYPE_VIRTUAL_CIRCUIT = "VIRTUAL_CIRCUIT"

    #: A constant which can be used with the type property of a DrgAttachmentNetworkDetails.
    #: This constant has a value of "REMOTE_PEERING_CONNECTION"
    TYPE_REMOTE_PEERING_CONNECTION = "REMOTE_PEERING_CONNECTION"

    def __init__(self, **kwargs):
        """
        Initializes a new DrgAttachmentNetworkDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.core.models.VcnDrgAttachmentNetworkDetails`
        * :class:`~oci.core.models.IpsecTunnelDrgAttachmentNetworkDetails`
        * :class:`~oci.core.models.VirtualCircuitDrgAttachmentNetworkDetails`
        * :class:`~oci.core.models.RemotePeeringConnectionDrgAttachmentNetworkDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this DrgAttachmentNetworkDetails.
            Allowed values for this property are: "VCN", "IPSEC_TUNNEL", "VIRTUAL_CIRCUIT", "REMOTE_PEERING_CONNECTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param id:
            The value to assign to the id property of this DrgAttachmentNetworkDetails.
        :type id: str

        """
        self.swagger_types = {
            'type': 'str',
            'id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'id': 'id'
        }

        self._type = None
        self._id = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'VCN':
            return 'VcnDrgAttachmentNetworkDetails'

        if type == 'IPSEC_TUNNEL':
            return 'IpsecTunnelDrgAttachmentNetworkDetails'

        if type == 'VIRTUAL_CIRCUIT':
            return 'VirtualCircuitDrgAttachmentNetworkDetails'

        if type == 'REMOTE_PEERING_CONNECTION':
            return 'RemotePeeringConnectionDrgAttachmentNetworkDetails'
        else:
            return 'DrgAttachmentNetworkDetails'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this DrgAttachmentNetworkDetails.
        Allowed values for this property are: "VCN", "IPSEC_TUNNEL", "VIRTUAL_CIRCUIT", "REMOTE_PEERING_CONNECTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this DrgAttachmentNetworkDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DrgAttachmentNetworkDetails.

        :param type: The type of this DrgAttachmentNetworkDetails.
        :type: str
        """
        allowed_values = ["VCN", "IPSEC_TUNNEL", "VIRTUAL_CIRCUIT", "REMOTE_PEERING_CONNECTION"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DrgAttachmentNetworkDetails.
        The `OCID`__ of the network attached to the DRG.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this DrgAttachmentNetworkDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DrgAttachmentNetworkDetails.
        The `OCID`__ of the network attached to the DRG.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this DrgAttachmentNetworkDetails.
        :type: str
        """
        self._id = id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetadataDetails(object):
    """
    Metadata parameter details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetadataDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param param_name:
            The value to assign to the param_name property of this MetadataDetails.
        :type param_name: str

        :param param_value:
            The value to assign to the param_value property of this MetadataDetails.
        :type param_value: str

        :param is_json_value:
            The value to assign to the is_json_value property of this MetadataDetails.
        :type is_json_value: bool

        """
        self.swagger_types = {
            'param_name': 'str',
            'param_value': 'str',
            'is_json_value': 'bool'
        }

        self.attribute_map = {
            'param_name': 'paramName',
            'param_value': 'paramValue',
            'is_json_value': 'isJsonValue'
        }

        self._param_name = None
        self._param_value = None
        self._is_json_value = None

    @property
    def param_name(self):
        """
        **[Required]** Gets the param_name of this MetadataDetails.
        Metadata param name


        :return: The param_name of this MetadataDetails.
        :rtype: str
        """
        return self._param_name

    @param_name.setter
    def param_name(self, param_name):
        """
        Sets the param_name of this MetadataDetails.
        Metadata param name


        :param param_name: The param_name of this MetadataDetails.
        :type: str
        """
        self._param_name = param_name

    @property
    def param_value(self):
        """
        **[Required]** Gets the param_value of this MetadataDetails.
        Metadata param value. Complex value will be a JSON string.


        :return: The param_value of this MetadataDetails.
        :rtype: str
        """
        return self._param_value

    @param_value.setter
    def param_value(self, param_value):
        """
        Sets the param_value of this MetadataDetails.
        Metadata param value. Complex value will be a JSON string.


        :param param_value: The param_value of this MetadataDetails.
        :type: str
        """
        self._param_value = param_value

    @property
    def is_json_value(self):
        """
        **[Required]** Gets the is_json_value of this MetadataDetails.
        Indicates if the value is a JSON string


        :return: The is_json_value of this MetadataDetails.
        :rtype: bool
        """
        return self._is_json_value

    @is_json_value.setter
    def is_json_value(self, is_json_value):
        """
        Sets the is_json_value of this MetadataDetails.
        Indicates if the value is a JSON string


        :param is_json_value: The is_json_value of this MetadataDetails.
        :type: bool
        """
        self._is_json_value = is_json_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_analytics_cluster_details import AddAnalyticsClusterDetails
from .add_heat_wave_cluster_details import AddHeatWaveClusterDetails
from .analytics_cluster import AnalyticsCluster
from .analytics_cluster_memory_estimate import AnalyticsClusterMemoryEstimate
from .analytics_cluster_node import AnalyticsClusterNode
from .analytics_cluster_schema_memory_estimate import AnalyticsClusterSchemaMemoryEstimate
from .analytics_cluster_summary import AnalyticsClusterSummary
from .analytics_cluster_table_memory_estimate import AnalyticsClusterTableMemoryEstimate
from .backup import Backup
from .backup_policy import BackupPolicy
from .backup_summary import BackupSummary
from .ca_certificate import CaCertificate
from .change_backup_compartment_details import ChangeBackupCompartmentDetails
from .channel import Channel
from .channel_source import ChannelSource
from .channel_source_mysql import ChannelSourceMysql
from .channel_summary import ChannelSummary
from .channel_target import ChannelTarget
from .channel_target_db_system import ChannelTargetDbSystem
from .configuration import Configuration
from .configuration_summary import ConfigurationSummary
from .configuration_variables import ConfigurationVariables
from .create_backup_details import CreateBackupDetails
from .create_backup_policy_details import CreateBackupPolicyDetails
from .create_channel_details import CreateChannelDetails
from .create_channel_source_details import CreateChannelSourceDetails
from .create_channel_source_from_mysql_details import CreateChannelSourceFromMysqlDetails
from .create_channel_target_details import CreateChannelTargetDetails
from .create_channel_target_from_db_system_details import CreateChannelTargetFromDbSystemDetails
from .create_configuration_details import CreateConfigurationDetails
from .create_db_system_details import CreateDbSystemDetails
from .create_db_system_source_details import CreateDbSystemSourceDetails
from .create_db_system_source_from_backup_details import CreateDbSystemSourceFromBackupDetails
from .create_db_system_source_from_none_details import CreateDbSystemSourceFromNoneDetails
from .create_db_system_source_import_from_url_details import CreateDbSystemSourceImportFromUrlDetails
from .create_maintenance_details import CreateMaintenanceDetails
from .db_system import DbSystem
from .db_system_endpoint import DbSystemEndpoint
from .db_system_placement import DbSystemPlacement
from .db_system_snapshot import DbSystemSnapshot
from .db_system_source import DbSystemSource
from .db_system_source_from_backup import DbSystemSourceFromBackup
from .db_system_source_from_none import DbSystemSourceFromNone
from .db_system_source_import_from_url import DbSystemSourceImportFromUrl
from .db_system_summary import DbSystemSummary
from .heat_wave_cluster import HeatWaveCluster
from .heat_wave_cluster_memory_estimate import HeatWaveClusterMemoryEstimate
from .heat_wave_cluster_schema_memory_estimate import HeatWaveClusterSchemaMemoryEstimate
from .heat_wave_cluster_summary import HeatWaveClusterSummary
from .heat_wave_cluster_table_memory_estimate import HeatWaveClusterTableMemoryEstimate
from .heat_wave_node import HeatWaveNode
from .maintenance_details import MaintenanceDetails
from .pem_ca_certificate import PemCaCertificate
from .restart_db_system_details import RestartDbSystemDetails
from .shape_summary import ShapeSummary
from .stop_db_system_details import StopDbSystemDetails
from .update_analytics_cluster_details import UpdateAnalyticsClusterDetails
from .update_backup_details import UpdateBackupDetails
from .update_backup_policy_details import UpdateBackupPolicyDetails
from .update_channel_details import UpdateChannelDetails
from .update_channel_source_details import UpdateChannelSourceDetails
from .update_channel_source_from_mysql_details import UpdateChannelSourceFromMysqlDetails
from .update_channel_target_details import UpdateChannelTargetDetails
from .update_channel_target_from_db_system_details import UpdateChannelTargetFromDbSystemDetails
from .update_configuration_details import UpdateConfigurationDetails
from .update_db_system_details import UpdateDbSystemDetails
from .update_heat_wave_cluster_details import UpdateHeatWaveClusterDetails
from .update_maintenance_details import UpdateMaintenanceDetails
from .version import Version
from .version_summary import VersionSummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for mysql services.
mysql_type_mapping = {
    "AddAnalyticsClusterDetails": AddAnalyticsClusterDetails,
    "AddHeatWaveClusterDetails": AddHeatWaveClusterDetails,
    "AnalyticsCluster": AnalyticsCluster,
    "AnalyticsClusterMemoryEstimate": AnalyticsClusterMemoryEstimate,
    "AnalyticsClusterNode": AnalyticsClusterNode,
    "AnalyticsClusterSchemaMemoryEstimate": AnalyticsClusterSchemaMemoryEstimate,
    "AnalyticsClusterSummary": AnalyticsClusterSummary,
    "AnalyticsClusterTableMemoryEstimate": AnalyticsClusterTableMemoryEstimate,
    "Backup": Backup,
    "BackupPolicy": BackupPolicy,
    "BackupSummary": BackupSummary,
    "CaCertificate": CaCertificate,
    "ChangeBackupCompartmentDetails": ChangeBackupCompartmentDetails,
    "Channel": Channel,
    "ChannelSource": ChannelSource,
    "ChannelSourceMysql": ChannelSourceMysql,
    "ChannelSummary": ChannelSummary,
    "ChannelTarget": ChannelTarget,
    "ChannelTargetDbSystem": ChannelTargetDbSystem,
    "Configuration": Configuration,
    "ConfigurationSummary": ConfigurationSummary,
    "ConfigurationVariables": ConfigurationVariables,
    "CreateBackupDetails": CreateBackupDetails,
    "CreateBackupPolicyDetails": CreateBackupPolicyDetails,
    "CreateChannelDetails": CreateChannelDetails,
    "CreateChannelSourceDetails": CreateChannelSourceDetails,
    "CreateChannelSourceFromMysqlDetails": CreateChannelSourceFromMysqlDetails,
    "CreateChannelTargetDetails": CreateChannelTargetDetails,
    "CreateChannelTargetFromDbSystemDetails": CreateChannelTargetFromDbSystemDetails,
    "CreateConfigurationDetails": CreateConfigurationDetails,
    "CreateDbSystemDetails": CreateDbSystemDetails,
    "CreateDbSystemSourceDetails": CreateDbSystemSourceDetails,
    "CreateDbSystemSourceFromBackupDetails": CreateDbSystemSourceFromBackupDetails,
    "CreateDbSystemSourceFromNoneDetails": CreateDbSystemSourceFromNoneDetails,
    "CreateDbSystemSourceImportFromUrlDetails": CreateDbSystemSourceImportFromUrlDetails,
    "CreateMaintenanceDetails": CreateMaintenanceDetails,
    "DbSystem": DbSystem,
    "DbSystemEndpoint": DbSystemEndpoint,
    "DbSystemPlacement": DbSystemPlacement,
    "DbSystemSnapshot": DbSystemSnapshot,
    "DbSystemSource": DbSystemSource,
    "DbSystemSourceFromBackup": DbSystemSourceFromBackup,
    "DbSystemSourceFromNone": DbSystemSourceFromNone,
    "DbSystemSourceImportFromUrl": DbSystemSourceImportFromUrl,
    "DbSystemSummary": DbSystemSummary,
    "HeatWaveCluster": HeatWaveCluster,
    "HeatWaveClusterMemoryEstimate": HeatWaveClusterMemoryEstimate,
    "HeatWaveClusterSchemaMemoryEstimate": HeatWaveClusterSchemaMemoryEstimate,
    "HeatWaveClusterSummary": HeatWaveClusterSummary,
    "HeatWaveClusterTableMemoryEstimate": HeatWaveClusterTableMemoryEstimate,
    "HeatWaveNode": HeatWaveNode,
    "MaintenanceDetails": MaintenanceDetails,
    "PemCaCertificate": PemCaCertificate,
    "RestartDbSystemDetails": RestartDbSystemDetails,
    "ShapeSummary": ShapeSummary,
    "StopDbSystemDetails": StopDbSystemDetails,
    "UpdateAnalyticsClusterDetails": UpdateAnalyticsClusterDetails,
    "UpdateBackupDetails": UpdateBackupDetails,
    "UpdateBackupPolicyDetails": UpdateBackupPolicyDetails,
    "UpdateChannelDetails": UpdateChannelDetails,
    "UpdateChannelSourceDetails": UpdateChannelSourceDetails,
    "UpdateChannelSourceFromMysqlDetails": UpdateChannelSourceFromMysqlDetails,
    "UpdateChannelTargetDetails": UpdateChannelTargetDetails,
    "UpdateChannelTargetFromDbSystemDetails": UpdateChannelTargetFromDbSystemDetails,
    "UpdateConfigurationDetails": UpdateConfigurationDetails,
    "UpdateDbSystemDetails": UpdateDbSystemDetails,
    "UpdateHeatWaveClusterDetails": UpdateHeatWaveClusterDetails,
    "UpdateMaintenanceDetails": UpdateMaintenanceDetails,
    "Version": Version,
    "VersionSummary": VersionSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import time

from .exceptions import MaximumWaitTimeExceeded, WaitUntilNotSupported, ServiceError
from .util import WAIT_RESOURCE_NOT_FOUND
from . import retry
from oci.work_requests.models import WorkRequest


def wait_until(client, response, property=None, state=None, max_interval_seconds=30, max_wait_seconds=1200, succeed_on_not_found=False, **kwargs):
    """Wait until the value of the given property in the response data has the given value.

    This will block the current thread until either the
    the desired state or the maximum wait time is reached. This is only
    supported for responses resulting from GET operations. A typical use
    case is to wait on an instance until it is in a running state.

    Although this can be run on any property of the data resulting from any
    GET operation, the most common use case is to check state properties on
    operations that GET a single object.

    The wait will poll at an increasing interval up to 'max_interval_seconds'
    for a maximum total time of 'max_wait_seconds'. If the maximum time
    is exceeded, then it will raise a MaximumWaitTimeExceeded error.

    On successful completion the final Response object will be returned. The
    original Response object will not be altered.

    If any responses result in an error, then the error will be thrown as normal
    resulting in the wait being aborted.

    :param client: A client we can use to call the service to periodically retrieve data.
    :param response: A Response object resulting from a GET operation.
    :param property: A string with the name of the property from the response data to evaluate.
        For example, 'state'.
    :param state: The value of the property that will indicate successful completion of the wait.
        Type corresponds to the property type.
    :param max_interval_seconds: (optional) The maximum interval between queries, in seconds.
        Defaults to 30 seconds.
    :param max_wait_seconds: (optional) The maximum time to wait, in seconds.
        Defaults to 1200 seconds.
    :param succeed_on_not_found: (optional) A boolean determining whether or not the waiter should return successfully
        if the data we're waiting on is not found (e.g. a 404 is returned from the service). This defaults to
        False and so a 404 would cause an exception to be thrown by this function. Setting it to True may be useful
        in scenarios when waiting for a resource to be terminated/deleted since it is possible that the resource would
        not be returned by the a GET call anymore.
    :param evaluate_response: (optional) A function which can be used to evaluate the response from the GET operation.
        This is a single argument function which takes in the response from the GET operation. If this function is
        supplied, then the 'property' argument cannot be supplied. It is expected that this function return a truthy
        value to signify that a condition has passed and the wait_until function should return, and a falsey value otherwise.
    :param wait_callback: (optional) A function which will be called each time that we have to do an initial wait (i.e.
        because the property of the resource was not in the correct state, or the ``evaluate_response`` function returned
         False). This function should take two arguments - the first argument is the number of times we have checked the
         resource, and the second argument is the result of the most recent check.
    :param fetch_func: (optional) This function will be called to fetch the updated state from the server.
        This can be used if the call to check for state needs to be more complex than a single GET request.
        For example, if the goal is to wait until an item appears in a list, fetch_func can be a function
        that paginates through a full list on the server.

    :return: The final response, which will contain the property in the specified state.

        If the ``succeed_on_not_found`` parameter is set to True and the data was not then ``oci.waiter.
        WAIT_RESOURCE_NOT_FOUND`` will be returned. This is a :py:class:`~oci.util.Sentinel` which is not truthy and
        holds an internal name of ``WaitResourceNotFound``.
    """

    if kwargs.get('evaluate_response') and (property):
        raise ValueError('Invalid wait_until configuration - can not provide both evaluate_response function and property argument, only one should be specified')
    elif not (kwargs.get('evaluate_response') or property):
        raise RuntimeError('Invalid wait_until configuration - neither a property argument, nor an evaluate_response function, have been specified')

    if kwargs.get('fetch_func') is None:
        # if no custom fetch_func is provided, we only support waiting on a GET request
        if response.request.method.lower() != 'get':
            raise WaitUntilNotSupported('wait_until is only supported for get operations.')

        # by default, re-issue response.request
        def default_fetch_func(response=None):
            return retry.DEFAULT_RETRY_STRATEGY.make_retrying_call(client.base_client.request, response.request)

        kwargs['fetch_func'] = default_fetch_func

    if property and not hasattr(response.data, property):
        raise ValueError('Response data does not contain the given property.')

    sleep_interval_seconds = 1
    start_time = time.time()

    times_checked = 0
    while True:
        if property:
            if isinstance(state, tuple):
                if getattr(response.data, property) in state:
                    return response
            elif getattr(response.data, property) == state:
                return response
        elif kwargs.get('evaluate_response')(response):
            return response

        if kwargs.get('wait_callback') and times_checked > 0:
            kwargs['wait_callback'](times_checked, response)

        elapsed_seconds = (time.time() - start_time)

        if elapsed_seconds + sleep_interval_seconds > max_wait_seconds:
            if max_wait_seconds <= elapsed_seconds:
                raise MaximumWaitTimeExceeded('Maximum wait time has been exceeded.')

        time.sleep(sleep_interval_seconds)

        # Double the sleep each time up to the maximum.
        sleep_interval_seconds = min(sleep_interval_seconds * 2, max_interval_seconds)

        try:
            response = kwargs.get('fetch_func')(response=response)
            times_checked += 1
        except ServiceError as se:
            if se.status == 404:
                if not succeed_on_not_found:
                    raise
                else:
                    # Returning the last good response may be disingenuous so instead return
                    # a sentinel flagging that the resource we tried to wait on was not
                    # found
                    return WAIT_RESOURCE_NOT_FOUND
            else:
                raise


# list of termination states for work request service used by composite operation waiters
_WORK_REQUEST_TERMINATION_STATES = [
    WorkRequest.STATUS_SUCCEEDED,
    WorkRequest.STATUS_FAILED,
    WorkRequest.STATUS_CANCELED
]



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AlertRuleSummary(object):
    """
    The alert rule.
    """

    #: A constant which can be used with the type property of a AlertRuleSummary.
    #: This constant has a value of "ACTUAL"
    TYPE_ACTUAL = "ACTUAL"

    #: A constant which can be used with the type property of a AlertRuleSummary.
    #: This constant has a value of "FORECAST"
    TYPE_FORECAST = "FORECAST"

    #: A constant which can be used with the threshold_type property of a AlertRuleSummary.
    #: This constant has a value of "PERCENTAGE"
    THRESHOLD_TYPE_PERCENTAGE = "PERCENTAGE"

    #: A constant which can be used with the threshold_type property of a AlertRuleSummary.
    #: This constant has a value of "ABSOLUTE"
    THRESHOLD_TYPE_ABSOLUTE = "ABSOLUTE"

    #: A constant which can be used with the lifecycle_state property of a AlertRuleSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AlertRuleSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new AlertRuleSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AlertRuleSummary.
        :type id: str

        :param budget_id:
            The value to assign to the budget_id property of this AlertRuleSummary.
        :type budget_id: str

        :param display_name:
            The value to assign to the display_name property of this AlertRuleSummary.
        :type display_name: str

        :param type:
            The value to assign to the type property of this AlertRuleSummary.
            Allowed values for this property are: "ACTUAL", "FORECAST", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param threshold:
            The value to assign to the threshold property of this AlertRuleSummary.
        :type threshold: float

        :param threshold_type:
            The value to assign to the threshold_type property of this AlertRuleSummary.
            Allowed values for this property are: "PERCENTAGE", "ABSOLUTE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type threshold_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AlertRuleSummary.
            Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param message:
            The value to assign to the message property of this AlertRuleSummary.
        :type message: str

        :param description:
            The value to assign to the description property of this AlertRuleSummary.
        :type description: str

        :param version:
            The value to assign to the version property of this AlertRuleSummary.
        :type version: int

        :param recipients:
            The value to assign to the recipients property of this AlertRuleSummary.
        :type recipients: str

        :param time_created:
            The value to assign to the time_created property of this AlertRuleSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AlertRuleSummary.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AlertRuleSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this AlertRuleSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'budget_id': 'str',
            'display_name': 'str',
            'type': 'str',
            'threshold': 'float',
            'threshold_type': 'str',
            'lifecycle_state': 'str',
            'message': 'str',
            'description': 'str',
            'version': 'int',
            'recipients': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'budget_id': 'budgetId',
            'display_name': 'displayName',
            'type': 'type',
            'threshold': 'threshold',
            'threshold_type': 'thresholdType',
            'lifecycle_state': 'lifecycleState',
            'message': 'message',
            'description': 'description',
            'version': 'version',
            'recipients': 'recipients',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._budget_id = None
        self._display_name = None
        self._type = None
        self._threshold = None
        self._threshold_type = None
        self._lifecycle_state = None
        self._message = None
        self._description = None
        self._version = None
        self._recipients = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AlertRuleSummary.
        The OCID of the alert rule


        :return: The id of this AlertRuleSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AlertRuleSummary.
        The OCID of the alert rule


        :param id: The id of this AlertRuleSummary.
        :type: str
        """
        self._id = id

    @property
    def budget_id(self):
        """
        **[Required]** Gets the budget_id of this AlertRuleSummary.
        The OCID of the budget


        :return: The budget_id of this AlertRuleSummary.
        :rtype: str
        """
        return self._budget_id

    @budget_id.setter
    def budget_id(self, budget_id):
        """
        Sets the budget_id of this AlertRuleSummary.
        The OCID of the budget


        :param budget_id: The budget_id of this AlertRuleSummary.
        :type: str
        """
        self._budget_id = budget_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this AlertRuleSummary.
        The name of the alert rule.


        :return: The display_name of this AlertRuleSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AlertRuleSummary.
        The name of the alert rule.


        :param display_name: The display_name of this AlertRuleSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this AlertRuleSummary.
        ACTUAL means the alert will trigger based on actual usage.
        FORECAST means the alert will trigger based on predicted usage.

        Allowed values for this property are: "ACTUAL", "FORECAST", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this AlertRuleSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AlertRuleSummary.
        ACTUAL means the alert will trigger based on actual usage.
        FORECAST means the alert will trigger based on predicted usage.


        :param type: The type of this AlertRuleSummary.
        :type: str
        """
        allowed_values = ["ACTUAL", "FORECAST"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def threshold(self):
        """
        **[Required]** Gets the threshold of this AlertRuleSummary.
        The threshold for triggering the alert. If thresholdType is PERCENTAGE, the maximum value is 10000.


        :return: The threshold of this AlertRuleSummary.
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """
        Sets the threshold of this AlertRuleSummary.
        The threshold for triggering the alert. If thresholdType is PERCENTAGE, the maximum value is 10000.


        :param threshold: The threshold of this AlertRuleSummary.
        :type: float
        """
        self._threshold = threshold

    @property
    def threshold_type(self):
        """
        **[Required]** Gets the threshold_type of this AlertRuleSummary.
        The type of threshold.

        Allowed values for this property are: "PERCENTAGE", "ABSOLUTE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The threshold_type of this AlertRuleSummary.
        :rtype: str
        """
        return self._threshold_type

    @threshold_type.setter
    def threshold_type(self, threshold_type):
        """
        Sets the threshold_type of this AlertRuleSummary.
        The type of threshold.


        :param threshold_type: The threshold_type of this AlertRuleSummary.
        :type: str
        """
        allowed_values = ["PERCENTAGE", "ABSOLUTE"]
        if not value_allowed_none_or_none_sentinel(threshold_type, allowed_values):
            threshold_type = 'UNKNOWN_ENUM_VALUE'
        self._threshold_type = threshold_type

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AlertRuleSummary.
        The current state of the alert rule.

        Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AlertRuleSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AlertRuleSummary.
        The current state of the alert rule.


        :param lifecycle_state: The lifecycle_state of this AlertRuleSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def message(self):
        """
        Gets the message of this AlertRuleSummary.
        Custom message that will be sent when alert is triggered


        :return: The message of this AlertRuleSummary.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this AlertRuleSummary.
        Custom message that will be sent when alert is triggered


        :param message: The message of this AlertRuleSummary.
        :type: str
        """
        self._message = message

    @property
    def description(self):
        """
        Gets the description of this AlertRuleSummary.
        The description of the alert rule.


        :return: The description of this AlertRuleSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AlertRuleSummary.
        The description of the alert rule.


        :param description: The description of this AlertRuleSummary.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this AlertRuleSummary.
        Version of the alert rule. Starts from 1 and increments by 1.


        :return: The version of this AlertRuleSummary.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this AlertRuleSummary.
        Version of the alert rule. Starts from 1 and increments by 1.


        :param version: The version of this AlertRuleSummary.
        :type: int
        """
        self._version = version

    @property
    def recipients(self):
        """
        **[Required]** Gets the recipients of this AlertRuleSummary.
        The audience that will receive the alert when it triggers.


        :return: The recipients of this AlertRuleSummary.
        :rtype: str
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """
        Sets the recipients of this AlertRuleSummary.
        The audience that will receive the alert when it triggers.


        :param recipients: The recipients of this AlertRuleSummary.
        :type: str
        """
        self._recipients = recipients

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AlertRuleSummary.
        Time when budget was created


        :return: The time_created of this AlertRuleSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AlertRuleSummary.
        Time when budget was created


        :param time_created: The time_created of this AlertRuleSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this AlertRuleSummary.
        Time when budget was updated


        :return: The time_updated of this AlertRuleSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this AlertRuleSummary.
        Time when budget was updated


        :param time_updated: The time_updated of this AlertRuleSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AlertRuleSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this AlertRuleSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AlertRuleSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this AlertRuleSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AlertRuleSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this AlertRuleSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AlertRuleSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this AlertRuleSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateApplianceExportJobDetails(object):
    """
    CreateApplianceExportJobDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateApplianceExportJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateApplianceExportJobDetails.
        :type compartment_id: str

        :param bucket_name:
            The value to assign to the bucket_name property of this CreateApplianceExportJobDetails.
        :type bucket_name: str

        :param display_name:
            The value to assign to the display_name property of this CreateApplianceExportJobDetails.
        :type display_name: str

        :param prefix:
            The value to assign to the prefix property of this CreateApplianceExportJobDetails.
        :type prefix: str

        :param range_start:
            The value to assign to the range_start property of this CreateApplianceExportJobDetails.
        :type range_start: str

        :param range_end:
            The value to assign to the range_end property of this CreateApplianceExportJobDetails.
        :type range_end: str

        :param customer_shipping_address:
            The value to assign to the customer_shipping_address property of this CreateApplianceExportJobDetails.
        :type customer_shipping_address: oci.dts.models.ShippingAddress

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateApplianceExportJobDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateApplianceExportJobDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'bucket_name': 'str',
            'display_name': 'str',
            'prefix': 'str',
            'range_start': 'str',
            'range_end': 'str',
            'customer_shipping_address': 'ShippingAddress',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'bucket_name': 'bucketName',
            'display_name': 'displayName',
            'prefix': 'prefix',
            'range_start': 'rangeStart',
            'range_end': 'rangeEnd',
            'customer_shipping_address': 'customerShippingAddress',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._bucket_name = None
        self._display_name = None
        self._prefix = None
        self._range_start = None
        self._range_end = None
        self._customer_shipping_address = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateApplianceExportJobDetails.

        :return: The compartment_id of this CreateApplianceExportJobDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateApplianceExportJobDetails.

        :param compartment_id: The compartment_id of this CreateApplianceExportJobDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this CreateApplianceExportJobDetails.

        :return: The bucket_name of this CreateApplianceExportJobDetails.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this CreateApplianceExportJobDetails.

        :param bucket_name: The bucket_name of this CreateApplianceExportJobDetails.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateApplianceExportJobDetails.

        :return: The display_name of this CreateApplianceExportJobDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateApplianceExportJobDetails.

        :param display_name: The display_name of this CreateApplianceExportJobDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def prefix(self):
        """
        Gets the prefix of this CreateApplianceExportJobDetails.
        List of objects with names matching this prefix would be part of this export job.


        :return: The prefix of this CreateApplianceExportJobDetails.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this CreateApplianceExportJobDetails.
        List of objects with names matching this prefix would be part of this export job.


        :param prefix: The prefix of this CreateApplianceExportJobDetails.
        :type: str
        """
        self._prefix = prefix

    @property
    def range_start(self):
        """
        Gets the range_start of this CreateApplianceExportJobDetails.
        Object names returned by a list query must be greater or equal to this parameter.


        :return: The range_start of this CreateApplianceExportJobDetails.
        :rtype: str
        """
        return self._range_start

    @range_start.setter
    def range_start(self, range_start):
        """
        Sets the range_start of this CreateApplianceExportJobDetails.
        Object names returned by a list query must be greater or equal to this parameter.


        :param range_start: The range_start of this CreateApplianceExportJobDetails.
        :type: str
        """
        self._range_start = range_start

    @property
    def range_end(self):
        """
        Gets the range_end of this CreateApplianceExportJobDetails.
        Object names returned by a list query must be strictly less than this parameter.


        :return: The range_end of this CreateApplianceExportJobDetails.
        :rtype: str
        """
        return self._range_end

    @range_end.setter
    def range_end(self, range_end):
        """
        Sets the range_end of this CreateApplianceExportJobDetails.
        Object names returned by a list query must be strictly less than this parameter.


        :param range_end: The range_end of this CreateApplianceExportJobDetails.
        :type: str
        """
        self._range_end = range_end

    @property
    def customer_shipping_address(self):
        """
        **[Required]** Gets the customer_shipping_address of this CreateApplianceExportJobDetails.

        :return: The customer_shipping_address of this CreateApplianceExportJobDetails.
        :rtype: oci.dts.models.ShippingAddress
        """
        return self._customer_shipping_address

    @customer_shipping_address.setter
    def customer_shipping_address(self, customer_shipping_address):
        """
        Sets the customer_shipping_address of this CreateApplianceExportJobDetails.

        :param customer_shipping_address: The customer_shipping_address of this CreateApplianceExportJobDetails.
        :type: oci.dts.models.ShippingAddress
        """
        self._customer_shipping_address = customer_shipping_address

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateApplianceExportJobDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateApplianceExportJobDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateApplianceExportJobDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateApplianceExportJobDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateApplianceExportJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateApplianceExportJobDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateApplianceExportJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateApplianceExportJobDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDeploymentDetails(object):
    """
    The information about a new Deployment.
    """

    #: A constant which can be used with the license_model property of a CreateDeploymentDetails.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a CreateDeploymentDetails.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    #: A constant which can be used with the deployment_type property of a CreateDeploymentDetails.
    #: This constant has a value of "OGG"
    DEPLOYMENT_TYPE_OGG = "OGG"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDeploymentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateDeploymentDetails.
        :type display_name: str

        :param license_model:
            The value to assign to the license_model property of this CreateDeploymentDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param description:
            The value to assign to the description property of this CreateDeploymentDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDeploymentDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDeploymentDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDeploymentDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param deployment_backup_id:
            The value to assign to the deployment_backup_id property of this CreateDeploymentDetails.
        :type deployment_backup_id: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateDeploymentDetails.
        :type subnet_id: str

        :param fqdn:
            The value to assign to the fqdn property of this CreateDeploymentDetails.
        :type fqdn: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateDeploymentDetails.
        :type nsg_ids: list[str]

        :param is_public:
            The value to assign to the is_public property of this CreateDeploymentDetails.
        :type is_public: bool

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this CreateDeploymentDetails.
        :type cpu_core_count: int

        :param is_auto_scaling_enabled:
            The value to assign to the is_auto_scaling_enabled property of this CreateDeploymentDetails.
        :type is_auto_scaling_enabled: bool

        :param deployment_type:
            The value to assign to the deployment_type property of this CreateDeploymentDetails.
            Allowed values for this property are: "OGG"
        :type deployment_type: str

        :param ogg_data:
            The value to assign to the ogg_data property of this CreateDeploymentDetails.
        :type ogg_data: oci.golden_gate.models.CreateOggDeploymentDetails

        """
        self.swagger_types = {
            'display_name': 'str',
            'license_model': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'deployment_backup_id': 'str',
            'subnet_id': 'str',
            'fqdn': 'str',
            'nsg_ids': 'list[str]',
            'is_public': 'bool',
            'cpu_core_count': 'int',
            'is_auto_scaling_enabled': 'bool',
            'deployment_type': 'str',
            'ogg_data': 'CreateOggDeploymentDetails'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'license_model': 'licenseModel',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'deployment_backup_id': 'deploymentBackupId',
            'subnet_id': 'subnetId',
            'fqdn': 'fqdn',
            'nsg_ids': 'nsgIds',
            'is_public': 'isPublic',
            'cpu_core_count': 'cpuCoreCount',
            'is_auto_scaling_enabled': 'isAutoScalingEnabled',
            'deployment_type': 'deploymentType',
            'ogg_data': 'oggData'
        }

        self._display_name = None
        self._license_model = None
        self._description = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._deployment_backup_id = None
        self._subnet_id = None
        self._fqdn = None
        self._nsg_ids = None
        self._is_public = None
        self._cpu_core_count = None
        self._is_auto_scaling_enabled = None
        self._deployment_type = None
        self._ogg_data = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateDeploymentDetails.
        An object's Display Name.


        :return: The display_name of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDeploymentDetails.
        An object's Display Name.


        :param display_name: The display_name of this CreateDeploymentDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def license_model(self):
        """
        **[Required]** Gets the license_model of this CreateDeploymentDetails.
        The Oracle license model that applies to a Deployment.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"


        :return: The license_model of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this CreateDeploymentDetails.
        The Oracle license model that applies to a Deployment.


        :param license_model: The license_model of this CreateDeploymentDetails.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            raise ValueError(
                "Invalid value for `license_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._license_model = license_model

    @property
    def description(self):
        """
        Gets the description of this CreateDeploymentDetails.
        Metadata about this specific object.


        :return: The description of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDeploymentDetails.
        Metadata about this specific object.


        :param description: The description of this CreateDeploymentDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDeploymentDetails.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDeploymentDetails.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateDeploymentDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDeploymentDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateDeploymentDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDeploymentDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateDeploymentDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDeploymentDetails.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateDeploymentDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDeploymentDetails.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateDeploymentDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def deployment_backup_id(self):
        """
        Gets the deployment_backup_id of this CreateDeploymentDetails.
        The `OCID`__ of the backup being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The deployment_backup_id of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._deployment_backup_id

    @deployment_backup_id.setter
    def deployment_backup_id(self, deployment_backup_id):
        """
        Sets the deployment_backup_id of this CreateDeploymentDetails.
        The `OCID`__ of the backup being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param deployment_backup_id: The deployment_backup_id of this CreateDeploymentDetails.
        :type: str
        """
        self._deployment_backup_id = deployment_backup_id

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this CreateDeploymentDetails.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateDeploymentDetails.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this CreateDeploymentDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def fqdn(self):
        """
        Gets the fqdn of this CreateDeploymentDetails.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :return: The fqdn of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._fqdn

    @fqdn.setter
    def fqdn(self, fqdn):
        """
        Sets the fqdn of this CreateDeploymentDetails.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :param fqdn: The fqdn of this CreateDeploymentDetails.
        :type: str
        """
        self._fqdn = fqdn

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateDeploymentDetails.
        An array of `Network Security Group`__ OCIDs used to define network access for a deployment.

        __ https://docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm


        :return: The nsg_ids of this CreateDeploymentDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateDeploymentDetails.
        An array of `Network Security Group`__ OCIDs used to define network access for a deployment.

        __ https://docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm


        :param nsg_ids: The nsg_ids of this CreateDeploymentDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def is_public(self):
        """
        Gets the is_public of this CreateDeploymentDetails.
        True if this object is publicly available.


        :return: The is_public of this CreateDeploymentDetails.
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """
        Sets the is_public of this CreateDeploymentDetails.
        True if this object is publicly available.


        :param is_public: The is_public of this CreateDeploymentDetails.
        :type: bool
        """
        self._is_public = is_public

    @property
    def cpu_core_count(self):
        """
        **[Required]** Gets the cpu_core_count of this CreateDeploymentDetails.
        The Minimum number of OCPUs to be made available for this Deployment.


        :return: The cpu_core_count of this CreateDeploymentDetails.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this CreateDeploymentDetails.
        The Minimum number of OCPUs to be made available for this Deployment.


        :param cpu_core_count: The cpu_core_count of this CreateDeploymentDetails.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def is_auto_scaling_enabled(self):
        """
        **[Required]** Gets the is_auto_scaling_enabled of this CreateDeploymentDetails.
        Indicates if auto scaling is enabled for the Deployment's CPU core count.


        :return: The is_auto_scaling_enabled of this CreateDeploymentDetails.
        :rtype: bool
        """
        return self._is_auto_scaling_enabled

    @is_auto_scaling_enabled.setter
    def is_auto_scaling_enabled(self, is_auto_scaling_enabled):
        """
        Sets the is_auto_scaling_enabled of this CreateDeploymentDetails.
        Indicates if auto scaling is enabled for the Deployment's CPU core count.


        :param is_auto_scaling_enabled: The is_auto_scaling_enabled of this CreateDeploymentDetails.
        :type: bool
        """
        self._is_auto_scaling_enabled = is_auto_scaling_enabled

    @property
    def deployment_type(self):
        """
        **[Required]** Gets the deployment_type of this CreateDeploymentDetails.
        The deployment type.

        Allowed values for this property are: "OGG"


        :return: The deployment_type of this CreateDeploymentDetails.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this CreateDeploymentDetails.
        The deployment type.


        :param deployment_type: The deployment_type of this CreateDeploymentDetails.
        :type: str
        """
        allowed_values = ["OGG"]
        if not value_allowed_none_or_none_sentinel(deployment_type, allowed_values):
            raise ValueError(
                "Invalid value for `deployment_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._deployment_type = deployment_type

    @property
    def ogg_data(self):
        """
        Gets the ogg_data of this CreateDeploymentDetails.

        :return: The ogg_data of this CreateDeploymentDetails.
        :rtype: oci.golden_gate.models.CreateOggDeploymentDetails
        """
        return self._ogg_data

    @ogg_data.setter
    def ogg_data(self, ogg_data):
        """
        Sets the ogg_data of this CreateDeploymentDetails.

        :param ogg_data: The ogg_data of this CreateDeploymentDetails.
        :type: oci.golden_gate.models.CreateOggDeploymentDetails
        """
        self._ogg_data = ogg_data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
